Vagas pra mim

Content of curriculum

software testing
wide
narrow

Similarity 10.7%

http://4alltests.com.br/vaga.php?id=272

Similarity 10.7%

http://4alltests.com.br/vaga.php?id=273

Similarity 8.7%

https://boards.greenhouse.io/tripadvisor/jobs/5015656

Similarity 8.4%

https://ciandt.com/us/en-us/careers/open-positions/enrollment?opportunity=23c97858-e8f8-4327-9833-3832d6be0c4d

Similarity 8.0%

https://boards.greenhouse.io/tripadvisor/jobs/5010533

Similarity 8.0%

https://boards.greenhouse.io/tripadvisor/jobs/5018108

Similarity 8.0%

https://boards.greenhouse.io/tripadvisor/jobs/5300644

Similarity 8.0%

https://careers.talkdesk.com/us/en/job/5076159/Financial-Systems-Analyst-NetSuite

Similarity 7.4%

https://www.volvogroup.com/br/careers/job-openings/142852BR.html

Similarity 7.3%

https://boards.greenhouse.io/tripadvisor/jobs/5117655

Similarity 6.8%

https://boards.greenhouse.io/thumbtack/jobs/5138569

Similarity 6.8%

https://boards.greenhouse.io/thumbtack/jobs/5138618

Similarity 6.7%

https://boards.greenhouse.io/thumbtack/jobs/5138538

Similarity 6.6%

https://boards.greenhouse.io/willowtree/jobs/6764898002

Similarity 6.3%

https://boards.greenhouse.io/thumbtack/jobs/5138380

Similarity 6.2%

https://boards.greenhouse.io/willowtree/jobs/6887218002

Similarity 6.2%

https://jobs.sap.com/job/Sofia-SAP-iXp-Intern-User-Experience-Designer-1407/965086101/

Similarity 6.1%

https://vivo.gupy.io/jobs/4901620?jobBoardSource=gupy_public_page

Similarity 6.1%

https://www.nerdwallet.com/careers/job/5262125

Similarity 5.9%

https://boards.greenhouse.io/ebanx/jobs/5506557003

Similarity 5.8%

https://www.nerdwallet.com/careers/job/5136596

Similarity 5.7%

https://jobs.lever.co/15five/f8592802-0bd8-41be-a596-db5bdd4e35bc

Similarity 5.7%

https://www.nerdwallet.com/careers/job/4979461

Similarity 5.3%

https://boards.greenhouse.io/checkr/jobs/5313010

Similarity 5.3%

https://boards.greenhouse.io/harrys/jobs/5305365

Similarity 5.2%

https://boards.greenhouse.io/checkr/jobs/5224402

Similarity 5.2%

https://boards.greenhouse.io/checkr/jobs/5262092

Similarity 4.4%

https://www.nerdwallet.com/blog/engineering/piggy/